move_target

Function move_target 

pub fn move_target(
    target: &Path,
    dest: &Path,
    allow_rename: bool,
    mode: &impl TestingMode,
    stream: &mut impl Write,
    force: bool,
    dirs_to_create: &[DirToCreate],
) -> Result<bool, Error>
Move a target to a given destination, copying if necessary. Returns true if the target was moved, false if it was not (due to user input)