Record

Struct Record 

pub struct Record<const FILE_LOCK: bool> { /* private fields */ }
A record of file operations maintained in the graveyard directory

Type Parameters

  • FILE_LOCK - When true, exclusive file locks are acquired when opening the record file for reading or writing. This prevents concurrent access from multiple processes. When false, no file locking is performed - which is used for testing.

Implementations

Source

impl<const FILE_LOCK: bool> Record<FILE_LOCK>

pub fn new(graveyard: &Path) -> Self

pub fn open(&self) -> Result<File, Error>

pub fn get_last_bury(&self) -> Result<PathBuf, Error>

Return the path in the graveyard of the last file to be buried. As a side effect, any valid last files that are found in the record but not on the filesystem are removed from the record.

pub fn log_exhumed_graves( &self, graves_to_exhume: &[PathBuf], ) -> Result<(), Error>

pub fn lines_of_graves<'a>( &'a self, graves: &'a [PathBuf], ) -> impl Iterator<Item = String> + 'a

Takes a vector of grave paths and returns the respective lines in the record

pub fn seance<'a>( &'a self, gravepath: &'a PathBuf, ) -> Result<impl Iterator<Item = RecordItem> + 'a>

Returns an iterator over all graves in the record that are under gravepath

pub fn write_log( &self, source: impl AsRef<Path>, dest: impl AsRef<Path>, ) -> Result<()>

Write deletion history to record