Module testing

Module testing 

Testing module for exposing internal functions to unit tests. This module is only used for testing purposes and should not be used in production code.

Functions

testable_should_we_bury_this