Function rip2::move_target
source · pub fn move_target(
target: &Path,
dest: &Path,
mode: &impl TestingMode,
stream: &mut impl Write
) -> Result<bool, Error>Expand description
Move a target to a given destination, copying if necessary. Returns true if the target was moved, false if it was not (due to user input)